@@ -26,23 +26,37 @@
 #include "utils.h"
 #include "gearman_utils.h"
 
-int opt_verbose    = GM_DISABLED;
-int opt_quiet      = GM_DISABLED;
-int opt_batch      = GM_DISABLED;
-int opt_interval   = 1;
+int opt_verbose     = GM_DISABLED;
+int opt_quiet       = GM_DISABLED;
+int opt_batch       = GM_DISABLED;
+int con_timeout     = 10;
+double opt_interval = 0;
 
 char * server_list[GM_LISTSIZE];
 int server_list_num = 0;
+char * version_saved = NULL;
 WINDOW *w;
 
+void catcher( int );
+void catcher( int sig ) {
+    gm_log( GM_LOG_DEBUG, "catcher(%d)\n", sig );
+    return;
+}
 
 /* work starts here */
 int main (int argc, char **argv) {
     int opt;
+    int i;
+    struct sigaction sact;
 
-    mod_gm_opt = malloc(sizeof(mod_gm_opt_t));
+    mod_gm_opt = gm_malloc(sizeof(mod_gm_opt_t));
     set_default_options(mod_gm_opt);
 
+    sigemptyset( &sact.sa_mask );
+    sact.sa_flags = 0;
+    sact.sa_handler = catcher;
+    sigaction( SIGALRM, &sact, NULL );
+
     /*
      * and parse command line
      */
@@ -59,7 +73,7 @@ int main (int argc, char **argv) {
                         break;
             case 'q':   opt_quiet = GM_ENABLED;
                         break;
-            case 'i':   opt_interval = atoi(optarg);
+            case 'i':   opt_interval = atof(optarg) * 1000000;
                         break;
             case 'b':   opt_batch = GM_ENABLED;
                         break;
@@ -74,18 +88,33 @@ int main (int argc, char **argv) {
         server_list[server_list_num++] = "localhost";
     server_list[server_list_num] = NULL;
 
-    if(opt_interval <= 0)
-        opt_interval = 1;
-
     signal(SIGINT, clean_exit);
     signal(SIGTERM,clean_exit);
 
     /* in batch mode, print stats once and exit */
     if(opt_batch == GM_ENABLED) {
-        print_stats(server_list[0]);
+        if(opt_interval > 0) {
+            while(1) {
+                for(i=0;i<server_list_num;i++) {
+                    alarm(con_timeout);
+                    print_stats(server_list[i]);
+                    alarm(0);
+                }
+                usleep(opt_interval);
+            }
+        } else {
+            for(i=0;i<server_list_num;i++) {
+                alarm(con_timeout);
+                print_stats(server_list[i]);
+                alarm(0);
+            }
+        }
         clean_exit(0);
     }
 
+    if(opt_interval <= 0)
+        opt_interval = 1000000;
+
     /* init curses */
     w = initscr();
     cbreak();
@@ -96,8 +125,14 @@ int main (int argc, char **argv) {
     while(1) {
         if(getch() == 'q')
             clean_exit(0);
-        print_stats(server_list[0]);
-        sleep(opt_interval);
+        if(opt_batch == GM_DISABLED)
+            erase(); /* clear screen */
+        for(i=0;i<server_list_num;i++) {
+            alarm(con_timeout);
+            print_stats(server_list[i]);
+            alarm(0);
+        }
+        usleep(opt_interval);
     }
 
     clean_exit(0);
@@ -140,7 +175,7 @@ void print_usage() {
 
 /* print stats */
 void print_stats(char * hostnam) {
-    char * hst    = strdup(hostnam);
+    char * hst    = gm_strdup(hostnam);
     char * hst_c  = hst;
     char * server = NULL;
     char * port_c = NULL;
@@ -166,21 +201,24 @@ void print_stats(char * hostnam) {
         port = atoi(port_c);
 
     /* get stats */
-    stats = malloc(sizeof(mod_gm_server_status_t));
+    stats = (mod_gm_server_status_t*)gm_malloc(sizeof(mod_gm_server_status_t));
     stats->function_num = 0;
-    stats->worker_num = 0;
+    stats->worker_num   = 0;
     rc = get_gearman_server_data(stats, &message, &version, server, port);
 
     t   = time(NULL);
     now = *(localtime(&t));
     strftime(cur_time, sizeof(cur_time), "%Y-%m-%d %H:%M:%S", &now );
 
-    if(opt_batch == GM_DISABLED) {
-        erase(); /* clear screen */
+    my_printf("%s  -  %s:%i", cur_time, server, port );
+    if(version != NULL && strcmp(version, "") != 0) {
+        if(version_saved != NULL)
+            free(version_saved);
+        version_saved = gm_strdup(version);
     }
-    my_printf("%s  -  %s:%i ", cur_time, server, port );
-    if(version != NULL && strcmp(version, "") != 0)
-        my_printf("  -  v%s", version );
+
+    if(version_saved != NULL && strcmp(version_saved, "") != 0)
+        my_printf("  -  v%s", version_saved );
     my_printf("\n\n");
 
     if( rc == STATE_OK ) {
